@@ -59,7 +59,7 @@ use_precommit_config <- function(config_source = getOption("precommit.config_sou
     write_union(fs::path(root, ".Rbuildignore"), escaped_name_target)
   }
   cli::cli_ul(c(
-    "Edit .precommit-hooks.yaml to (de)activate the hooks you want to use. ",
+    "Edit .precommit-config.yaml to (de)activate the hooks you want to use. ",
     "All available hooks: https://pre-commit.com/hooks.html",
     paste("R specific hooks:", hooks_repo)
   ))
